{
    "$graph": [
        {
            "class": "ExpressionTool",
            "id": "#expression_checkcontamination.cwl",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "loadContents": true
                    },
                    "id": "#expression_checkcontamination.cwl/expression_checkcontamination/verifybamid_selfsm"
                }
            ],
            "expression": "${ var lines=inputs.verifybamid_selfsm.contents.split('\\n'); for (var i=1; i<lines.length; i++){ var fields=lines[i].split('\\t'); if (fields.length != 19) {continue;} return {contamination: fields[6]/0.75}; } }",
            "outputs": [
                {
                    "type": "float",
                    "id": "#expression_checkcontamination.cwl/expression_checkcontamination/contamination"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "id": "#gatk_applybqsr.cwl",
            "requirements": [
                {
                    "class": "ShellCommandRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "kfdrc/gatk:4.0.3.0"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 5000
                }
            ],
            "baseCommand": [
                "/gatk",
                "ApplyBQSR"
            ],
            "arguments": [
                {
                    "position": 1,
                    "shellQuote": false,
                    "valueFrom": "--java-options \"-Xms3000m -XX:+PrintFlagsFinal -XX:+PrintGCTimeStamps -XX:+PrintGCDateStamps -XX:+PrintGCDetails -Xloggc:gc_log.log -XX:GCTimeLimit=50 -XX:GCHeapFreeLimit=10\" --create-output-bam-md5 --add-output-sam-program-record -R $(inputs.reference.path) -I $(inputs.input_bam.path) --use-original-qualities -O $(inputs.input_bam.nameroot).aligned.duplicates_marked.recalibrated.bam -bqsr $(inputs.bqsr_report.path) --static-quantized-quals 10 --static-quantized-quals 20 --static-quantized-quals 30 -L $(inputs.sequence_interval.path)"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#gatk_applybqsr.cwl/gatk4_applybqsr/bqsr_report"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        "^.bai"
                    ],
                    "id": "#gatk_applybqsr.cwl/gatk4_applybqsr/input_bam"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        "^.dict",
                        ".fai"
                    ],
                    "id": "#gatk_applybqsr.cwl/gatk4_applybqsr/reference"
                },
                {
                    "type": "File",
                    "id": "#gatk_applybqsr.cwl/gatk4_applybqsr/sequence_interval"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "*bam"
                    },
                    "secondaryFiles": [
                        "^.bai",
                        ".md5"
                    ],
                    "id": "#gatk_applybqsr.cwl/gatk4_applybqsr/recalibrated_bam"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "id": "#gatk_baserecalibrator.cwl",
            "requirements": [
                {
                    "class": "ShellCommandRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "kfdrc/gatk:4.0.3.0"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 10000
                }
            ],
            "baseCommand": [
                "/gatk",
                "BaseRecalibrator"
            ],
            "arguments": [
                {
                    "position": 0,
                    "shellQuote": false,
                    "valueFrom": "--java-options \"-Xms5000m -XX:GCTimeLimit=50 -XX:GCHeapFreeLimit=10 -XX:+PrintFlagsFinal -XX:+PrintGCTimeStamps -XX:+PrintGCDateStamps -XX:+PrintGCDetails -Xloggc:gc_log.log\" -R $(inputs.reference.path) -I $(inputs.input_bam.path) --use-original-qualities -O $(inputs.input_bam.nameroot).recal_data.csv -L $(inputs.sequence_interval.path)"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "secondaryFiles": [
                        "^.bai"
                    ],
                    "id": "#gatk_baserecalibrator.cwl/gatkv4_baserecalibrator/input_bam"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File",
                        "inputBinding": {
                            "prefix": "--known-sites"
                        }
                    },
                    "inputBinding": {
                        "position": 1
                    },
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#gatk_baserecalibrator.cwl/gatkv4_baserecalibrator/knownsites"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        "^.dict",
                        ".fai"
                    ],
                    "id": "#gatk_baserecalibrator.cwl/gatkv4_baserecalibrator/reference"
                },
                {
                    "type": "File",
                    "id": "#gatk_baserecalibrator.cwl/gatkv4_baserecalibrator/sequence_interval"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "*.recal_data.csv"
                    },
                    "id": "#gatk_baserecalibrator.cwl/gatkv4_baserecalibrator/output"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "id": "#gatk_gatherbqsrreports.cwl",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "ShellCommandRequirement"
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "kfdrc/gatk:4.0.3.0"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 8000
                }
            ],
            "baseCommand": [
                "/gatk",
                "GatherBQSRReports"
            ],
            "arguments": [
                {
                    "position": 1,
                    "shellQuote": false,
                    "valueFrom": "--java-options \"-Xms3000m\" -O $(inputs.output_basename).GatherBqsrReports.recal_data.csv"
                }
            ],
            "inputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File",
                        "inputBinding": {
                            "prefix": "-I",
                            "separate": true
                        }
                    },
                    "id": "#gatk_gatherbqsrreports.cwl/gatk_gatherbqsrreports/input_brsq_reports"
                },
                {
                    "type": "string",
                    "id": "#gatk_gatherbqsrreports.cwl/gatk_gatherbqsrreports/output_basename"
                }
            ],
            "outputs": [
                {
                    "id": "#gatk_gatherbqsrreports.cwl/gatk_gatherbqsrreports/output",
                    "type": "File",
                    "outputBinding": {
                        "glob": "*.csv"
                    }
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "id": "#gatk_haplotypecaller.cwl",
            "requirements": [
                {
                    "class": "ShellCommandRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 10000
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "kfdrc/gatk:4.beta.1-3.5"
                }
            ],
            "baseCommand": [
                "/gatk-launch",
                "--javaOptions",
                "-Xms2000m"
            ],
            "arguments": [
                {
                    "position": 1,
                    "shellQuote": false,
                    "valueFrom": "PrintReads -I $(inputs.input_bam.path) --interval_padding 500 -L $(inputs.interval_list.path) -O local.sharded.bam && java -XX:GCTimeLimit=50 -XX:GCHeapFreeLimit=10 -Xms8000m -jar /GenomeAnalysisTK.jar -T HaplotypeCaller -R $(inputs.reference.path) -o $(inputs.input_bam.nameroot).vcf.gz -I local.sharded.bam -L $(inputs.interval_list.path) -ERC GVCF --max_alternate_alleles 3 -variant_index_parameter 128000 -variant_index_type LINEAR -contamination $(inputs.contamination) --read_filter OverclippedRead"
                }
            ],
            "inputs": [
                {
                    "type": "float",
                    "id": "#gatk_haplotypecaller.cwl/gatk_haplotypecaller/contamination"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        "^.bai"
                    ],
                    "id": "#gatk_haplotypecaller.cwl/gatk_haplotypecaller/input_bam"
                },
                {
                    "type": "File",
                    "id": "#gatk_haplotypecaller.cwl/gatk_haplotypecaller/interval_list"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        "^.dict",
                        ".fai"
                    ],
                    "id": "#gatk_haplotypecaller.cwl/gatk_haplotypecaller/reference"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "*.vcf.gz"
                    },
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#gatk_haplotypecaller.cwl/gatk_haplotypecaller/output"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "id": "#picard_collectaggregationmetrics.cwl",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "ShellCommandRequirement"
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "kfdrc/picard-r:latest-dev"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 12000
                }
            ],
            "baseCommand": [
                "java",
                "-Xms5000m",
                "-jar",
                "/picard.jar",
                "CollectMultipleMetrics"
            ],
            "arguments": [
                {
                    "position": 1,
                    "shellQuote": false,
                    "valueFrom": "INPUT=$(inputs.input_bam.path) REFERENCE_SEQUENCE=$(inputs.reference.path) OUTPUT=$(inputs.input_bam.nameroot) ASSUME_SORTED=true PROGRAM=\"null\" PROGRAM=\"CollectAlignmentSummaryMetrics\"  PROGRAM=\"CollectInsertSizeMetrics\"  PROGRAM=\"CollectSequencingArtifactMetrics\"  PROGRAM=\"CollectGcBiasMetrics\"  PROGRAM=\"QualityScoreDistribution\"  METRIC_ACCUMULATION_LEVEL=\"null\"  METRIC_ACCUMULATION_LEVEL=\"SAMPLE\"  METRIC_ACCUMULATION_LEVEL=\"LIBRARY\""
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "secondaryFiles": [
                        "^.bai"
                    ],
                    "id": "#picard_collectaggregationmetrics.cwl/picard_collectaggregationmetrics/input_bam"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        "^.dict",
                        ".fai"
                    ],
                    "id": "#picard_collectaggregationmetrics.cwl/picard_collectaggregationmetrics/reference"
                }
            ],
            "outputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputBinding": {
                        "glob": "$(inputs.input_bam.nameroot).*"
                    },
                    "id": "#picard_collectaggregationmetrics.cwl/picard_collectaggregationmetrics/output"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "id": "#picard_collectgvcfcallingmetrics.cwl",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "ShellCommandRequirement"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 3000,
                    "coresMin": 16
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "kfdrc/picard:2.18.2-dev"
                }
            ],
            "baseCommand": [
                "java",
                "-Xms2000m",
                "-jar",
                "/picard.jar",
                "CollectVariantCallingMetrics"
            ],
            "arguments": [
                {
                    "position": 1,
                    "shellQuote": false,
                    "valueFrom": "INPUT=$(inputs.input_vcf.path) OUTPUT=$(inputs.final_gvcf_base_name) DBSNP=$(inputs.dbsnp_vcf.path) SEQUENCE_DICTIONARY=$(inputs.reference_dict.path) TARGET_INTERVALS=$(inputs.wgs_evaluation_interval_list.path) GVCF_INPUT=true THREAD_COUNT=16"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".idx"
                    ],
                    "id": "#picard_collectgvcfcallingmetrics.cwl/gatk_collectgvcfcallingmetrics/dbsnp_vcf"
                },
                {
                    "type": "string",
                    "id": "#picard_collectgvcfcallingmetrics.cwl/gatk_collectgvcfcallingmetrics/final_gvcf_base_name"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#picard_collectgvcfcallingmetrics.cwl/gatk_collectgvcfcallingmetrics/input_vcf"
                },
                {
                    "type": "File",
                    "id": "#picard_collectgvcfcallingmetrics.cwl/gatk_collectgvcfcallingmetrics/reference_dict"
                },
                {
                    "type": "File",
                    "id": "#picard_collectgvcfcallingmetrics.cwl/gatk_collectgvcfcallingmetrics/wgs_evaluation_interval_list"
                }
            ],
            "outputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputBinding": {
                        "glob": "*_metrics"
                    },
                    "id": "#picard_collectgvcfcallingmetrics.cwl/gatk_collectgvcfcallingmetrics/output"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "id": "#picard_collectwgsmetrics.cwl",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "ShellCommandRequirement"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 8000
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "kfdrc/picard:2.18.2-dev"
                }
            ],
            "baseCommand": [
                "java",
                "-Xms2000m",
                "-jar",
                "/picard.jar",
                "CollectWgsMetrics"
            ],
            "arguments": [
                {
                    "position": 1,
                    "shellQuote": false,
                    "valueFrom": "INPUT=$(inputs.input_bam.path) VALIDATION_STRINGENCY=SILENT REFERENCE_SEQUENCE=$(inputs.reference.path) INCLUDE_BQ_HISTOGRAM=true INTERVALS=$(inputs.intervals.path) OUTPUT=$(inputs.input_bam.nameroot).wgs_metrics USE_FAST_ALGORITHM=true READ_LENGTH=250"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "secondaryFiles": [
                        "^.bai"
                    ],
                    "id": "#picard_collectwgsmetrics.cwl/picard_collectwgsmetrics/input_bam"
                },
                {
                    "type": "File",
                    "id": "#picard_collectwgsmetrics.cwl/picard_collectwgsmetrics/intervals"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".fai"
                    ],
                    "id": "#picard_collectwgsmetrics.cwl/picard_collectwgsmetrics/reference"
                }
            ],
            "outputs": [
                {
                    "id": "#picard_collectwgsmetrics.cwl/picard_collectwgsmetrics/output",
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.input_bam.nameroot).wgs_metrics"
                    }
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "id": "#picard_gatherbamfiles.cwl",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "ShellCommandRequirement"
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "kfdrc/picard:2.18.2-dev"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 8000
                }
            ],
            "baseCommand": [],
            "arguments": [
                {
                    "position": 1,
                    "shellQuote": false,
                    "valueFrom": "rm_bams=\"${\n  var arr = [];\n  for (var i=0; i<inputs.input_bam.length; i++)\n      arr = arr.concat(inputs.input_bam[i].path)\n  return (arr.join(' '))\n}\"\ninput_bams=\"${\n  var arr = [];\n  for (var i=0; i<inputs.input_bam.length; i++)\n      arr = arr.concat(inputs.input_bam[i].path)\n  return (arr.join(' INPUT='))\n}\"\njava -Xms2000m -jar /picard.jar GatherBamFiles OUTPUT=$(inputs.output_bam_basename).bam INPUT=$input_bams CREATE_INDEX=true CREATE_MD5_FILE=true && rm $rm_bams"
                }
            ],
            "inputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "secondaryFiles": [
                        "^.bai"
                    ],
                    "id": "#picard_gatherbamfiles.cwl/picard_gatherbamfiles/input_bam"
                },
                {
                    "type": "string",
                    "id": "#picard_gatherbamfiles.cwl/picard_gatherbamfiles/output_bam_basename"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "*.bam"
                    },
                    "secondaryFiles": [
                        "^.bai",
                        ".md5"
                    ],
                    "id": "#picard_gatherbamfiles.cwl/picard_gatherbamfiles/output"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "id": "#picard_intervallisttools.cwl",
            "requirements": [
                {
                    "class": "ShellCommandRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "kfdrc/picard:2.18.2-dev"
                }
            ],
            "baseCommand": [
                "java",
                "-Xmx2000m",
                "-jar",
                "/picard.jar"
            ],
            "arguments": [
                {
                    "position": 1,
                    "shellQuote": false,
                    "valueFrom": "IntervalListTools SCATTER_COUNT=50 SUBDIVISION_MODE=BALANCING_WITHOUT_INTERVAL_SUBDIVISION_WITH_OVERFLOW UNIQUE=true SORT=true BREAK_BANDS_AT_MULTIPLES_OF=1000000 INPUT=$(inputs.interval_list.path) OUTPUT=$(runtime.outdir)"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#picard_intervallisttools.cwl/picard_intervallisttools/interval_list"
                }
            ],
            "outputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputBinding": {
                        "glob": "temp*/*.interval_list"
                    },
                    "id": "#picard_intervallisttools.cwl/picard_intervallisttools/output"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "id": "#picard_mergevcfs.cwl",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "ShellCommandRequirement"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 3000
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "kfdrc/picard:2.18.2-dev"
                }
            ],
            "baseCommand": [
                "java",
                "-Xms2000m",
                "-jar",
                "/picard.jar",
                "MergeVcfs"
            ],
            "arguments": [
                {
                    "position": 1,
                    "shellQuote": false,
                    "valueFrom": "OUTPUT=$(inputs.output_vcf_basename).g.vcf.gz"
                }
            ],
            "inputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File",
                        "inputBinding": {
                            "prefix": "INPUT=",
                            "separate": false
                        }
                    },
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#picard_mergevcfs.cwl/picard_mergevcfs/input_vcf"
                },
                {
                    "type": "string",
                    "id": "#picard_mergevcfs.cwl/picard_mergevcfs/output_vcf_basename"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "*.vcf.gz"
                    },
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#picard_mergevcfs.cwl/picard_mergevcfs/output"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "id": "#python_createsequencegroups.cwl",
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "kfdrc/python:2.7.13"
                },
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "baseCommand": [
                "python",
                "-c"
            ],
            "arguments": [
                {
                    "position": 0,
                    "valueFrom": "def main():\n    with open(\"$(inputs.ref_dict.path)\", \"r\") as ref_dict_file:\n        sequence_tuple_list = []\n        longest_sequence = 0\n        for line in ref_dict_file:\n            if line.startswith(\"@SQ\"):\n                line_split = line.split(\"\\t\")\n                sequence_tuple_list.append((line_split[1].split(\"SN:\")[1], int(line_split[2].split(\"LN:\")[1])))\n        longest_sequence = sorted(sequence_tuple_list, key=lambda x: x[1], reverse=True)[0][1]\n    hg38_protection_tag = \":1+\"\n    tsv_string = sequence_tuple_list[0][0] + hg38_protection_tag\n    temp_size = sequence_tuple_list[0][1]\n    i = 0\n    for sequence_tuple in sequence_tuple_list[1:]:\n        if temp_size + sequence_tuple[1] <= longest_sequence:\n            temp_size += sequence_tuple[1]\n            tsv_string += \"\\n\" + sequence_tuple[0] + hg38_protection_tag\n        else:\n            i += 1\n            pad = \"{:0>2d}\".format(i)\n            tsv_file_name = \"sequence_grouping_\" + pad + \".intervals\"\n            with open(tsv_file_name, \"w\") as tsv_file:\n                tsv_file.write(tsv_string)\n                tsv_file.close()\n            tsv_string = sequence_tuple[0] + hg38_protection_tag\n            temp_size = sequence_tuple[1]\n    i += 1\n    pad = \"{:0>2d}\".format(i)\n    tsv_file_name = \"sequence_grouping_\" + pad + \".intervals\"\n    with open(tsv_file_name, \"w\") as tsv_file:\n        tsv_file.write(tsv_string)\n        tsv_file.close()\n\n    with open(\"unmapped.intervals\", \"w\") as tsv_file:\n        tsv_file.write(\"unmapped\")\n        tsv_file.close()\n\nif __name__ == \"__main__\":\n    main()"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#python_createsequencegroups.cwl/python_createsequencegroups/ref_dict"
                }
            ],
            "outputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputBinding": {
                        "glob": "sequence_grouping_*.intervals"
                    },
                    "id": "#python_createsequencegroups.cwl/python_createsequencegroups/sequence_intervals"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputBinding": {
                        "glob": "*.intervals"
                    },
                    "id": "#python_createsequencegroups.cwl/python_createsequencegroups/sequence_intervals_with_unmapped"
                }
            ]
        },
        {
            "class": "Workflow",
            "inputs": [
                {
                    "type": "string",
                    "id": "#snpeff-workflow.cwl/genome"
                },
                {
                    "type": "File",
                    "doc": "VCF file to annotate",
                    "id": "#snpeff-workflow.cwl/infile"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#snpeff-workflow.cwl/snpeff/genes",
                    "id": "#snpeff-workflow.cwl/genesfile"
                },
                {
                    "type": "File",
                    "outputSource": "#snpeff-workflow.cwl/snpeff/output",
                    "id": "#snpeff-workflow.cwl/outfile"
                },
                {
                    "type": "File",
                    "outputSource": "#snpeff-workflow.cwl/snpeff/stats",
                    "id": "#snpeff-workflow.cwl/statsfile"
                }
            ],
            "steps": [
                {
                    "run": "#snpeff.cwl",
                    "in": [
                        {
                            "source": "#snpeff-workflow.cwl/genome",
                            "id": "#snpeff-workflow.cwl/snpeff/genome"
                        },
                        {
                            "source": "#snpeff-workflow.cwl/infile",
                            "id": "#snpeff-workflow.cwl/snpeff/input_vcf"
                        }
                    ],
                    "out": [
                        "#snpeff-workflow.cwl/snpeff/output",
                        "#snpeff-workflow.cwl/snpeff/stats",
                        "#snpeff-workflow.cwl/snpeff/genes"
                    ],
                    "id": "#snpeff-workflow.cwl/snpeff"
                }
            ],
            "doc": "Annotate variants provided in a VCF using SnpEff\n",
            "id": "#snpeff-workflow.cwl"
        },
        {
            "class": "CommandLineTool",
            "baseCommand": [],
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "chusj/snpeff"
                }
            ],
            "inputs": [
                {
                    "type": "string",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#snpeff.cwl/genome"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 2
                    },
                    "doc": "VCF file to annotate",
                    "id": "#snpeff.cwl/input_vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "*.txt"
                    },
                    "id": "#snpeff.cwl/genes"
                },
                {
                    "type": "File",
                    "id": "#snpeff.cwl/output",
                    "outputBinding": {
                        "glob": "output.vcf"
                    }
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "*.html"
                    },
                    "id": "#snpeff.cwl/stats"
                }
            ],
            "stdout": "output.vcf",
            "id": "#snpeff.cwl"
        },
        {
            "class": "CommandLineTool",
            "id": "#verifybamid.cwl",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "ShellCommandRequirement"
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "kfdrc/verifybamid:1.0.2"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 5000,
                    "coresMin": 4
                }
            ],
            "baseCommand": [
                "/bin/VerifyBamID"
            ],
            "arguments": [
                {
                    "position": 1,
                    "shellQuote": false,
                    "valueFrom": "--Verbose --NumPC 4 --Output $(inputs.output_basename) --BamFile $(inputs.input_bam.path) --Reference $(inputs.ref_fasta.path) --UDPath $(inputs.contamination_sites_ud.path) --MeanPath $(inputs.contamination_sites_mu.path) --BedPath $(inputs.contamination_sites_bed.path) 1>/dev/null"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#verifybamid.cwl/verifybamid/contamination_sites_bed"
                },
                {
                    "type": "File",
                    "id": "#verifybamid.cwl/verifybamid/contamination_sites_mu"
                },
                {
                    "type": "File",
                    "id": "#verifybamid.cwl/verifybamid/contamination_sites_ud"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        "^.bai"
                    ],
                    "id": "#verifybamid.cwl/verifybamid/input_bam"
                },
                {
                    "type": "string",
                    "id": "#verifybamid.cwl/verifybamid/output_basename"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".fai"
                    ],
                    "id": "#verifybamid.cwl/verifybamid/ref_fasta"
                }
            ],
            "outputs": [
                {
                    "id": "#verifybamid.cwl/verifybamid/output",
                    "type": "File",
                    "outputBinding": {
                        "glob": "*.selfSM"
                    }
                }
            ]
        },
        {
            "class": "Workflow",
            "id": "#main",
            "requirements": [
                {
                    "class": "ScatterFeatureRequirement"
                },
                {
                    "class": "MultipleInputFeatureRequirement"
                },
                {
                    "class": "SubworkflowFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#main/contamination_sites_bed"
                },
                {
                    "type": "File",
                    "id": "#main/contamination_sites_mu"
                },
                {
                    "type": "File",
                    "id": "#main/contamination_sites_ud"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".idx"
                    ],
                    "id": "#main/dbsnp_vcf"
                },
                {
                    "type": "string",
                    "id": "#main/genome"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".64.amb",
                        ".fai",
                        "^.dict",
                        ".64.ann",
                        ".64.bwt",
                        ".64.pac",
                        ".64.sa",
                        ".64.alt",
                        "^.dict",
                        ".amb",
                        ".ann",
                        ".bwt",
                        ".pac",
                        ".sa"
                    ],
                    "id": "#main/indexed_reference_fasta"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#main/knownsites"
                },
                {
                    "type": "string",
                    "id": "#main/output_basename"
                },
                {
                    "type": "File",
                    "id": "#main/reference_dict"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".bai"
                    ],
                    "id": "#main/sorted_bam"
                },
                {
                    "type": "File",
                    "id": "#main/wgs_calling_interval_list"
                },
                {
                    "type": "File",
                    "id": "#main/wgs_coverage_interval_list"
                },
                {
                    "type": "File",
                    "id": "#main/wgs_evaluation_interval_list"
                }
            ],
            "outputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/picard_collectaggregationmetrics/output",
                    "id": "#main/aggregation_metrics"
                },
                {
                    "type": "File",
                    "outputSource": "#main/snpeff_g_vcf/outfile",
                    "id": "#main/annotated_vcf"
                },
                {
                    "type": "File",
                    "outputSource": "#main/gatk_gatherbqsrreports/output",
                    "id": "#main/bqsr_report"
                },
                {
                    "type": "File",
                    "outputSource": "#main/picard_mergevcfs/output",
                    "id": "#main/gvcf"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/picard_collectgvcfcallingmetrics/output",
                    "id": "#main/gvcf_calling_metrics"
                },
                {
                    "type": "File",
                    "outputSource": "#main/verifybamid/output",
                    "id": "#main/verifybamid_output"
                },
                {
                    "type": "File",
                    "outputSource": "#main/picard_collectwgsmetrics/output",
                    "id": "#main/wgs_metrics"
                }
            ],
            "steps": [
                {
                    "run": "#expression_checkcontamination.cwl",
                    "in": [
                        {
                            "source": "#main/verifybamid/output",
                            "id": "#main/checkcontamination/verifybamid_selfsm"
                        }
                    ],
                    "out": [
                        "#main/checkcontamination/contamination"
                    ],
                    "id": "#main/checkcontamination"
                },
                {
                    "run": "#gatk_applybqsr.cwl",
                    "in": [
                        {
                            "source": "#main/gatk_gatherbqsrreports/output",
                            "id": "#main/gatk_applybqsr/bqsr_report"
                        },
                        {
                            "source": "#main/sorted_bam",
                            "id": "#main/gatk_applybqsr/input_bam"
                        },
                        {
                            "source": "#main/indexed_reference_fasta",
                            "id": "#main/gatk_applybqsr/reference"
                        },
                        {
                            "source": "#main/python_createsequencegroups/sequence_intervals",
                            "id": "#main/gatk_applybqsr/sequence_interval"
                        }
                    ],
                    "scatter": [
                        "#main/gatk_applybqsr/sequence_interval"
                    ],
                    "out": [
                        "#main/gatk_applybqsr/recalibrated_bam"
                    ],
                    "id": "#main/gatk_applybqsr"
                },
                {
                    "run": "#gatk_baserecalibrator.cwl",
                    "in": [
                        {
                            "source": "#main/sorted_bam",
                            "id": "#main/gatk_baserecalibrator/input_bam"
                        },
                        {
                            "source": "#main/knownsites",
                            "id": "#main/gatk_baserecalibrator/knownsites"
                        },
                        {
                            "source": "#main/indexed_reference_fasta",
                            "id": "#main/gatk_baserecalibrator/reference"
                        },
                        {
                            "source": "#main/python_createsequencegroups/sequence_intervals",
                            "id": "#main/gatk_baserecalibrator/sequence_interval"
                        }
                    ],
                    "scatter": [
                        "#main/gatk_baserecalibrator/sequence_interval"
                    ],
                    "out": [
                        "#main/gatk_baserecalibrator/output"
                    ],
                    "id": "#main/gatk_baserecalibrator"
                },
                {
                    "run": "#gatk_gatherbqsrreports.cwl",
                    "in": [
                        {
                            "source": "#main/gatk_baserecalibrator/output",
                            "id": "#main/gatk_gatherbqsrreports/input_brsq_reports"
                        },
                        {
                            "source": "#main/output_basename",
                            "id": "#main/gatk_gatherbqsrreports/output_basename"
                        }
                    ],
                    "out": [
                        "#main/gatk_gatherbqsrreports/output"
                    ],
                    "id": "#main/gatk_gatherbqsrreports"
                },
                {
                    "run": "#gatk_haplotypecaller.cwl",
                    "in": [
                        {
                            "source": "#main/checkcontamination/contamination",
                            "id": "#main/gatk_haplotypecaller/contamination"
                        },
                        {
                            "source": "#main/picard_gatherbamfiles/output",
                            "id": "#main/gatk_haplotypecaller/input_bam"
                        },
                        {
                            "source": "#main/picard_intervallisttools/output",
                            "id": "#main/gatk_haplotypecaller/interval_list"
                        },
                        {
                            "source": "#main/indexed_reference_fasta",
                            "id": "#main/gatk_haplotypecaller/reference"
                        }
                    ],
                    "scatter": [
                        "#main/gatk_haplotypecaller/interval_list"
                    ],
                    "out": [
                        "#main/gatk_haplotypecaller/output"
                    ],
                    "id": "#main/gatk_haplotypecaller"
                },
                {
                    "run": "#picard_collectaggregationmetrics.cwl",
                    "in": [
                        {
                            "source": "#main/picard_gatherbamfiles/output",
                            "id": "#main/picard_collectaggregationmetrics/input_bam"
                        },
                        {
                            "source": "#main/indexed_reference_fasta",
                            "id": "#main/picard_collectaggregationmetrics/reference"
                        }
                    ],
                    "out": [
                        "#main/picard_collectaggregationmetrics/output"
                    ],
                    "id": "#main/picard_collectaggregationmetrics"
                },
                {
                    "run": "#picard_collectgvcfcallingmetrics.cwl",
                    "in": [
                        {
                            "source": "#main/dbsnp_vcf",
                            "id": "#main/picard_collectgvcfcallingmetrics/dbsnp_vcf"
                        },
                        {
                            "source": "#main/output_basename",
                            "id": "#main/picard_collectgvcfcallingmetrics/final_gvcf_base_name"
                        },
                        {
                            "source": "#main/picard_mergevcfs/output",
                            "id": "#main/picard_collectgvcfcallingmetrics/input_vcf"
                        },
                        {
                            "source": "#main/reference_dict",
                            "id": "#main/picard_collectgvcfcallingmetrics/reference_dict"
                        },
                        {
                            "source": "#main/wgs_evaluation_interval_list",
                            "id": "#main/picard_collectgvcfcallingmetrics/wgs_evaluation_interval_list"
                        }
                    ],
                    "out": [
                        "#main/picard_collectgvcfcallingmetrics/output"
                    ],
                    "id": "#main/picard_collectgvcfcallingmetrics"
                },
                {
                    "run": "#picard_collectwgsmetrics.cwl",
                    "in": [
                        {
                            "source": "#main/picard_gatherbamfiles/output",
                            "id": "#main/picard_collectwgsmetrics/input_bam"
                        },
                        {
                            "source": "#main/wgs_coverage_interval_list",
                            "id": "#main/picard_collectwgsmetrics/intervals"
                        },
                        {
                            "source": "#main/indexed_reference_fasta",
                            "id": "#main/picard_collectwgsmetrics/reference"
                        }
                    ],
                    "out": [
                        "#main/picard_collectwgsmetrics/output"
                    ],
                    "id": "#main/picard_collectwgsmetrics"
                },
                {
                    "run": "#picard_gatherbamfiles.cwl",
                    "in": [
                        {
                            "source": "#main/gatk_applybqsr/recalibrated_bam",
                            "id": "#main/picard_gatherbamfiles/input_bam"
                        },
                        {
                            "source": "#main/output_basename",
                            "id": "#main/picard_gatherbamfiles/output_bam_basename"
                        }
                    ],
                    "out": [
                        "#main/picard_gatherbamfiles/output"
                    ],
                    "id": "#main/picard_gatherbamfiles"
                },
                {
                    "run": "#picard_intervallisttools.cwl",
                    "in": [
                        {
                            "source": "#main/wgs_calling_interval_list",
                            "id": "#main/picard_intervallisttools/interval_list"
                        }
                    ],
                    "out": [
                        "#main/picard_intervallisttools/output"
                    ],
                    "id": "#main/picard_intervallisttools"
                },
                {
                    "run": "#picard_mergevcfs.cwl",
                    "in": [
                        {
                            "source": "#main/gatk_haplotypecaller/output",
                            "id": "#main/picard_mergevcfs/input_vcf"
                        },
                        {
                            "source": "#main/output_basename",
                            "id": "#main/picard_mergevcfs/output_vcf_basename"
                        }
                    ],
                    "out": [
                        "#main/picard_mergevcfs/output"
                    ],
                    "id": "#main/picard_mergevcfs"
                },
                {
                    "run": "#python_createsequencegroups.cwl",
                    "in": [
                        {
                            "source": "#main/reference_dict",
                            "id": "#main/python_createsequencegroups/ref_dict"
                        }
                    ],
                    "out": [
                        "#main/python_createsequencegroups/sequence_intervals"
                    ],
                    "id": "#main/python_createsequencegroups"
                },
                {
                    "run": "#snpeff-workflow.cwl",
                    "in": [
                        {
                            "source": "#main/genome",
                            "id": "#main/snpeff_g_vcf/genome"
                        },
                        {
                            "source": "#main/picard_mergevcfs/output",
                            "id": "#main/snpeff_g_vcf/infile"
                        }
                    ],
                    "out": [
                        "#main/snpeff_g_vcf/outfile",
                        "#main/snpeff_g_vcf/statsfile",
                        "#main/snpeff_g_vcf/genesfile"
                    ],
                    "id": "#main/snpeff_g_vcf"
                },
                {
                    "run": "#verifybamid.cwl",
                    "in": [
                        {
                            "source": "#main/contamination_sites_bed",
                            "id": "#main/verifybamid/contamination_sites_bed"
                        },
                        {
                            "source": "#main/contamination_sites_mu",
                            "id": "#main/verifybamid/contamination_sites_mu"
                        },
                        {
                            "source": "#main/contamination_sites_ud",
                            "id": "#main/verifybamid/contamination_sites_ud"
                        },
                        {
                            "source": "#main/sorted_bam",
                            "id": "#main/verifybamid/input_bam"
                        },
                        {
                            "source": "#main/output_basename",
                            "id": "#main/verifybamid/output_basename"
                        },
                        {
                            "source": "#main/indexed_reference_fasta",
                            "id": "#main/verifybamid/ref_fasta"
                        }
                    ],
                    "out": [
                        "#main/verifybamid/output"
                    ],
                    "id": "#main/verifybamid"
                }
            ],
            "hints": [
                {
                    "class": "https://sevenbridges.comAWSInstanceType",
                    "value": "c4.8xlarge;ebs-gp2;850"
                },
                {
                    "class": "https://sevenbridges.commaxNumberOfParallelInstances",
                    "value": 4
                }
            ]
        }
    ],
    "cwlVersion": "v1.0",
    "$namespaces": {
        "sbg": "https://sevenbridges.com"
    }
}
